@@ -4,9 +4,9 @@
 format_spark_probs <- function(results, object) {
   results <- dplyr::select(results, starts_with("probability_"))
   p <- ncol(results)
-  lvl <- paste0("probability_", 0:(p - 1))
-  names(lvl) <- paste0("pred_", object$fit$.index_labels)
-  results %>% rename(!!!syms(lvl))
+  lvl <- colnames(results)
+  names(lvl) <- paste0("pred_", object$fit$index_labels)
+  results %>% dplyr::rename(!!!syms(lvl))
 }
 
 format_spark_class <- function(results, object) {
