@@ -1,6 +1,6 @@
 #' General Interface for Linear Regression Models
 #'
-#' `linear_reg` is a way to generate a _specification_ of a model
+#' `linear_reg()` is a way to generate a _specification_ of a model
 #'  before fitting and allows the model to be created using
 #'  different packages in R, Stan, keras, or via Spark. The main
 #'  arguments for the model are:
@@ -12,9 +12,9 @@
 #' }
 #' These arguments are converted to their specific names at the
 #'  time that the model is fit. Other options and argument can be
-#'  set using `set_engine`. If left to their defaults
+#'  set using `set_engine()`. If left to their defaults
 #'  here (`NULL`), the values are taken from the underlying model
-#'  functions. If parameters need to be modified, `update` can be used
+#'  functions. If parameters need to be modified, `update()` can be used
 #'  in lieu of recreating the object from scratch.
 #' @inheritParams boost_tree
 #' @param mode A single character string for the type of model.
@@ -30,7 +30,7 @@
 #'  (the lasso) (`glmnet` and `spark` only).
 #' @details
 #' The data given to the function are not saved and are only used
-#'  to determine the _mode_ of the model. For `linear_reg`, the
+#'  to determine the _mode_ of the model. For `linear_reg()`, the
 #'  mode will always be "regression".
 #'
 #' The model can be created using the `fit()` function using the
@@ -63,20 +63,20 @@
 #' \pkg{spark}
 #'
 #' \Sexpr[results=rd]{parsnip:::show_fit(parsnip:::linear_reg(), "spark")}
-#' 
+#'
 #' \pkg{keras}
 #'
 #' \Sexpr[results=rd]{parsnip:::show_fit(parsnip:::linear_reg(), "keras")}
 #'
 #' When using `glmnet` models, there is the option to pass
-#'  multiple values (or no values) to the `penalty` argument.
-#'  This can have an effect on the model object results. When using
-#'  the `predict` method in these cases, the return object type
-#'  depends on the value of `penalty`. If a single value is
-#'  given, the results will be a simple numeric vector. When
-#'  multiple values or no values for `penalty` are used in
-#'  `linear_reg`, the `predict` method will return a data frame with
-#'  columns `values` and `lambda`.
+#'  multiple values (or no values) to the `penalty` argument. This
+#'  can have an effect on the model object results. When using the
+#'  `predict()` method in these cases, the return value depends on
+#'  the value of `penalty`. When using `predict()`, only a single
+#'  value of the penalty can be used. When predicting on multiple
+#'  penalties, the `multi_predict()` function can be used. It
+#'  returns a tibble with a list column called `.pred` that contains
+#'  a tibble with all of the penalty results.
 #'
 #' For prediction, the `stan` engine can compute posterior
 #'  intervals analogous to confidence and prediction intervals. In
@@ -87,13 +87,13 @@
 #'
 #' @note For models created using the spark engine, there are
 #'  several differences to consider. First, only the formula
-#'  interface to via `fit` is available; using `fit_xy` will
+#'  interface to via `fit()` is available; using `fit_xy()` will
 #'  generate an error. Second, the predictions will always be in a
 #'  spark table format. The names will be the same as documented but
 #'  without the dots. Third, there is no equivalent to factor
 #'  columns in spark tables so class predictions are returned as
 #'  character columns. Fourth, to retain the model object for a new
-#'  R session (via `save`), the `model$fit` element of the `parsnip`
+#'  R session (via `save()`), the `model$fit` element of the `parsnip`
 #'  object should be serialized via `ml_save(object$fit)` and
 #'  separately saved to disk. In a new session, the object can be
 #'  reloaded and reattached to the `parsnip` object.
@@ -130,7 +130,7 @@ print.linear_reg <- function(x, ...) {
   cat("Linear Regression Model Specification (", x$mode, ")\n\n", sep = "")
   model_printer(x, ...)
 
-  if(!is.null(x$method$fit$args)) {
+  if (!is.null(x$method$fit$args)) {
     cat("Model fit template:\n")
     print(show_call(x))
   }
@@ -216,12 +216,66 @@ organize_glmnet_pred <- function(x, object) {
 
 # ------------------------------------------------------------------------------
 
+# For `predict` methods that use `glmnet`, we have specific methods.
+# Only one value of the penalty should be allowed when called by `predict()`:
+
+check_penalty <- function(penalty = NULL, object, multi = FALSE) {
+
+  if (is.null(penalty)) {
+    penalty <- object$fit$lambda
+  }
+
+  # when using `predict()`, allow for a single lambda
+  if (!multi) {
+    if (length(penalty) != 1)
+      stop("`penalty` should be a single numeric value. ",
+           "`multi_predict()` can be used to get multiple predictions ",
+           "per row of data.", call. = FALSE)
+  }
+
+  if (length(object$fit$lambda) == 1 && penalty != object$fit$lambda)
+    stop("The glmnet model was fit with a single penalty value of ",
+         object$fit$lambda, ". Predicting with a value of ",
+         penalty, " will give incorrect results from `glmnet()`.",
+         call. = FALSE)
+
+  penalty
+}
+
+# ------------------------------------------------------------------------------
+# glmnet call stack for linear regression using `predict` when object has
+# classes "_elnet" and "model_fit":
+#
+#  predict()
+# 	predict._elnet(penalty = NULL)   <-- checks and sets penalty
+#    predict.model_fit()             <-- checks for extra vars in ...
+#     predict_numeric()
+#      predict_numeric._elnet()
+#       predict_numeric.model_fit()
+#        predict.elnet()
+
+
+# glmnet call stack for linear regression using `multi_predict` when object has
+# classes "_elnet" and "model_fit":
+#
+# 	multi_predict()
+#    multi_predict._elnet(penalty = NULL)
+#      predict._elnet(multi = TRUE)          <-- checks and sets penalty
+#       predict.model_fit()                  <-- checks for extra vars in ...
+#        predict_raw()
+#         predict_raw._elnet()
+#          predict_raw.model_fit(opts = list(s = penalty))
+#           predict.elnet()
+
+
 #' @export
 predict._elnet <-
-  function(object, new_data, type = NULL, opts = list(), ...) {
+  function(object, new_data, type = NULL, opts = list(), penalty = NULL, multi = FALSE, ...) {
     if (any(names(enquos(...)) == "newdata"))
       stop("Did you mean to use `new_data` instead of `newdata`?", call. = FALSE)
-    
+
+    object$spec$args$penalty <- check_penalty(penalty, object, multi)
+
     object$spec <- eval_args(object$spec)
     predict.model_fit(object, new_data = new_data, type = type, opts = opts, ...)
   }
@@ -230,7 +284,7 @@ predict._elnet <-
 predict_numeric._elnet <- function(object, new_data, ...) {
   if (any(names(enquos(...)) == "newdata"))
     stop("Did you mean to use `new_data` instead of `newdata`?", call. = FALSE)
-  
+
   object$spec <- eval_args(object$spec)
   predict_numeric.model_fit(object, new_data = new_data, ...)
 }
@@ -239,8 +293,9 @@ predict_numeric._elnet <- function(object, new_data, ...) {
 predict_raw._elnet <- function(object, new_data, opts = list(), ...)  {
   if (any(names(enquos(...)) == "newdata"))
     stop("Did you mean to use `new_data` instead of `newdata`?", call. = FALSE)
-  
+
   object$spec <- eval_args(object$spec)
+  opts$s <- object$spec$args$penalty
   predict_raw.model_fit(object, new_data = new_data, opts = opts, ...)
 }
 
@@ -251,14 +306,17 @@ multi_predict._elnet <-
   function(object, new_data, type = NULL, penalty = NULL, ...) {
     if (any(names(enquos(...)) == "newdata"))
       stop("Did you mean to use `new_data` instead of `newdata`?", call. = FALSE)
-    
+
     dots <- list(...)
-    if (is.null(penalty))
-      penalty <- object$fit$lambda
-    dots$s <- penalty
 
     object$spec <- eval_args(object$spec)
-    pred <- predict(object, new_data = new_data, type = "raw", opts = dots)
+
+    if (is.null(penalty)) {
+      penalty <- object$fit$lambda
+    }
+
+    pred <- predict._elnet(object, new_data = new_data, type = "raw",
+                           opts = dots, penalty = penalty, multi = TRUE)
     param_key <- tibble(group = colnames(pred), penalty = penalty)
     pred <- as_tibble(pred)
     pred$.row <- 1:nrow(pred)
