@@ -1,6 +1,6 @@
 #' General Interface for Multinomial Regression Models
 #'
-#' `multinom_reg` is a way to generate a _specification_ of a model
+#' `multinom_reg()` is a way to generate a _specification_ of a model
 #'  before fitting and allows the model to be created using
 #'  different packages in R, keras, or Spark. The main arguments for the
 #'  model are:
@@ -12,9 +12,9 @@
 #' }
 #' These arguments are converted to their specific names at the
 #'  time that the model is fit. Other options and argument can be
-#'  set using `set_engine`. If left to their defaults
+#'  set using `set_engine()`. If left to their defaults
 #'  here (`NULL`), the values are taken from the underlying model
-#'  functions. If parameters need to be modified, `update` can be used
+#'  functions. If parameters need to be modified, `update()` can be used
 #'  in lieu of recreating the object from scratch.
 #' @inheritParams boost_tree
 #' @param mode A single character string for the type of model.
@@ -29,7 +29,7 @@
 #'  L2 penalty (i.e. weight decay, or ridge regression) versus L1
 #'  (the lasso) (`glmnet` only).
 #' @details
-#' For `multinom_reg`, the mode will always be "classification".
+#' For `multinom_reg()`, the mode will always be "classification".
 #'
 #' The model can be created using the `fit()` function using the
 #'  following _engines_:
@@ -58,24 +58,24 @@
 #' \Sexpr[results=rd]{parsnip:::show_fit(parsnip:::multinom_reg(), "keras")}
 #'
 #' When using `glmnet` models, there is the option to pass
-#'  multiple values (or no values) to the `penalty` argument.
-#'  This can have an effect on the model object results. When using
-#'  the `predict` method in these cases, the return object type
-#'  depends on the value of `penalty`. If a single value is
-#'  given, the results will be a simple numeric vector. When
-#'  multiple values or no values for `penalty` are used in
-#'  `multinom_reg`, the `predict` method will return a data frame with
-#'  columns `values` and `lambda`.
+#'  multiple values (or no values) to the `penalty` argument. This
+#'  can have an effect on the model object results. When using the
+#'  `predict()` method in these cases, the return value depends on
+#'  the value of `penalty`. When using `predict()`, only a single
+#'  value of the penalty can be used. When predicting on multiple
+#'  penalties, the `multi_predict()` function can be used. It
+#'  returns a tibble with a list column called `.pred` that contains
+#'  a tibble with all of the penalty results.
 #'
 #' @note For models created using the spark engine, there are
 #'  several differences to consider. First, only the formula
-#'  interface to via `fit` is available; using `fit_xy` will
+#'  interface to via `fit()` is available; using `fit_xy()` will
 #'  generate an error. Second, the predictions will always be in a
 #'  spark table format. The names will be the same as documented but
 #'  without the dots. Third, there is no equivalent to factor
 #'  columns in spark tables so class predictions are returned as
 #'  character columns. Fourth, to retain the model object for a new
-#'  R session (via `save`), the `model$fit` element of the `parsnip`
+#'  R session (via `save()`), the `model$fit` element of the `parsnip`
 #'  object should be serialized via `ml_save(object$fit)` and
 #'  separately saved to disk. In a new session, the object can be
 #'  reloaded and reattached to the `parsnip` object.
@@ -168,7 +168,7 @@ check_args.multinom_reg <- function(object) {
 
   args <- lapply(object$args, rlang::eval_tidy)
 
-  if (is.numeric(args$penalty) && args$penalty < 0)
+  if (all(is.numeric(args$penalty)) && any(args$penalty < 0))
     stop("The amount of regularization should be >= 0", call. = FALSE)
   if (is.numeric(args$mixture) && (args$mixture < 0 | args$mixture > 1))
     stop("The mixture proportion should be within [0,1]", call. = FALSE)
@@ -184,60 +184,50 @@ organize_multnet_class <- function(x, object) {
 
 organize_multnet_prob <- function(x, object) {
   x <- x[,,1]
-  x <- as_tibble(x)
-  names(x) <- paste0(".pred_", names(x))
-  x
+  as_tibble(x)
 }
 
+# ------------------------------------------------------------------------------
+# glmnet call stack for linear regression using `predict` when object has
+# classes "_multnet" and "model_fit" (for class predictions):
+#
+#  predict()
+# 	predict._multnet(penalty = NULL)   <-- checks and sets penalty
+#    predict.model_fit()               <-- checks for extra vars in ...
+#     predict_class()
+#      predict_class._multnet()
+#       predict.multnet()
+
+
+# glmnet call stack for linear regression using `multi_predict` when object has
+# classes "_multnet" and "model_fit" (for class predictions):
+#
+# 	multi_predict()
+#    multi_predict._multnet(penalty = NULL)
+#      predict._multnet(multi = TRUE)          <-- checks and sets penalty
+#       predict.model_fit()                    <-- checks for extra vars in ...
+#        predict_raw()
+#         predict_raw._multnet()
+#          predict_raw.model_fit(opts = list(s = penalty))
+#           predict.multnet()
+
 # ------------------------------------------------------------------------------
 
-#' @export
-predict._lognet <- function (object, new_data, type = NULL, opts = list(), ...) {
-  object$spec <- eval_args(object$spec)
-  predict.model_fit(object, new_data = new_data, type = type, opts = opts, ...)
-}
-
-#' @export
-predict_class._lognet <- function (object, new_data, ...) {
-  object$spec <- eval_args(object$spec)
-  predict_class.model_fit(object, new_data = new_data, ...)
-}
-
-#' @export
-predict_classprob._multnet <- function (object, new_data, ...) {
-  object$spec <- eval_args(object$spec)
-  predict_classprob.model_fit(object, new_data = new_data, ...)
-}
-
-#' @export
-predict_raw._multnet <- function (object, new_data, opts = list(), ...) {
-  object$spec <- eval_args(object$spec)
-  predict_raw.model_fit(object, new_data = new_data, opts = opts, ...)
-}
-
-
 #' @export
 predict._multnet <-
-  function(object, new_data, type = NULL, opts = list(), penalty = NULL, ...) {
-    dots <- list(...)
-    if (is.null(penalty))
-      penalty <- object$fit$lambda
+  function(object, new_data, type = NULL, opts = list(), penalty = NULL, multi = FALSE, ...) {
+
+    object$spec$args$penalty <- check_penalty(penalty, object, multi)
 
-  if (length(penalty) != 1)
-    stop("`penalty` should be a single numeric value. ",
-         "`multi_predict` can be used to get multiple predictions ",
-         "per row of data.", call. = FALSE)
     object$spec <- eval_args(object$spec)
     res <- predict.model_fit(
       object = object,
       new_data = new_data,
       type = type,
-      opts = opts,
-      penalty = penalty
+      opts = opts
     )
-  res
-}
-
+    res
+  }
 
 #' @importFrom dplyr full_join as_tibble arrange
 #' @importFrom tidyr gather
@@ -246,19 +236,19 @@ multi_predict._multnet <-
   function(object, new_data, type = NULL, penalty = NULL, ...) {
     if (any(names(enquos(...)) == "newdata"))
       stop("Did you mean to use `new_data` instead of `newdata`?", call. = FALSE)
-    
+
     if (is_quosure(penalty))
       penalty <- eval_tidy(penalty)
 
     dots <- list(...)
     if (is.null(penalty))
-      penalty <- eval_tidy(object$lambda)
+      penalty <- eval_tidy(object$fit$lambda)
     dots$s <- penalty
 
     if (is.null(type))
       type <- "class"
-    if (!(type %in% c("class", "prob", "link"))) {
-      stop ("`type` should be either 'class', 'link', or 'prob'.", call. = FALSE)
+    if (!(type %in% c("class", "prob", "link", "raw"))) {
+      stop ("`type` should be either 'class', 'link', 'raw', or 'prob'.", call. = FALSE)
     }
     if (type == "prob")
       dots$type <- "response"
@@ -298,12 +288,35 @@ multi_predict._multnet <-
     tibble(.pred = pred)
   }
 
+#' @export
+predict_class._multnet <- function (object, new_data, ...) {
+  object$spec <- eval_args(object$spec)
+  predict_class.model_fit(object, new_data = new_data, ...)
+}
+
+#' @export
+predict_classprob._multnet <- function (object, new_data, ...) {
+  object$spec <- eval_args(object$spec)
+  predict_classprob.model_fit(object, new_data = new_data, ...)
+}
+
+#' @export
+predict_raw._multnet <- function (object, new_data, opts = list(), ...) {
+  object$spec <- eval_args(object$spec)
+  predict_raw.model_fit(object, new_data = new_data, opts = opts, ...)
+}
+
+
+
+# ------------------------------------------------------------------------------
+
+# This checks as a pre-processor in the model data object
 check_glmnet_lambda <- function(dat, object) {
   if (length(object$fit$lambda) > 1)
     stop(
-      "`predict` doesn't work with multiple penalties (i.e. lambdas). ",
+      "`predict()` doesn't work with multiple penalties (i.e. lambdas). ",
       "Please specify a single value using `penalty = some_value` or use ",
-      "`multi_predict` to get multiple predictions per row of data.",
+      "`multi_predict()` to get multiple predictions per row of data.",
       call. = FALSE
     )
   dat
