@@ -1,21 +1,26 @@
-#' Other predict methods.
-#'
-#' These are internal functions not meant to be directly called by the user.
-#'
-#' @keywords internal
-#' @rdname other_predict
-#' @inheritParams predict.model_fit
-#' @method predict_class model_fit
-#' @export predict_class.model_fit
-#' @export
-predict_class.model_fit <- function (object, new_data, ...) {
-  if(object$spec$mode != "classification")
-    stop("`predict.model_fit` is for predicting factor outcomes.",
+# Other predict methods.
+#
+# These are internal functions not meant to be directly called by the user.
+#
+# @keywords internal
+# @rdname other_predict
+# @inheritParams predict.model_fit
+# @method predict_class model_fit
+# @export predict_class.model_fit
+# @export
+predict_class.model_fit <- function(object, new_data, ...) {
+  if (object$spec$mode != "classification")
+    stop("`predict.model_fit()` is for predicting factor outcomes.",
          call. = FALSE)
 
   if (!any(names(object$spec$method) == "class"))
     stop("No class prediction module defined for this model.", call. = FALSE)
 
+  if (inherits(object$fit, "try-error")) {
+    warning("Model fit failed; cannot make predictions.", call. = FALSE)
+    return(NULL)
+  }
+
   new_data <- prepare_data(object, new_data)
 
   # preprocess data
@@ -28,7 +33,7 @@ predict_class.model_fit <- function (object, new_data, ...) {
   res <- eval_tidy(pred_call)
 
   # post-process the predictions
-  if(!is.null(object$spec$method$class$post)) {
+  if (!is.null(object$spec$method$class$post)) {
     res <- object$spec$method$class$post(res, object)
   }
 
@@ -43,9 +48,10 @@ predict_class.model_fit <- function (object, new_data, ...) {
   res
 }
 
-#' @export
-#' @keywords internal
-#' @rdname other_predict
-#' @inheritParams predict.model_fit
-predict_class <- function (object, ...)
+# @export
+# @keywords internal
+# @rdname other_predict
+# @inheritParams predict.model_fit
+predict_class <- function(object, ...)
   UseMethod("predict_class")
+
