@@ -1,19 +1,24 @@
-#' @keywords internal
-#' @rdname other_predict
-#' @inheritParams predict.model_fit
-#' @method predict_numeric model_fit
-#' @export predict_numeric.model_fit
-#' @export
+# @keywords internal
+# @rdname other_predict
+# @inheritParams predict.model_fit
+# @method predict_numeric model_fit
+# @export predict_numeric.model_fit
+# @export
 
-predict_numeric.model_fit <- function (object, new_data, ...) {
+predict_numeric.model_fit <- function(object, new_data, ...) {
   if (object$spec$mode != "regression")
-    stop("`predict_numeric` is for predicting numeric outcomes.  ",
-         "Use `predict_class` or `predict_prob` for ",
+    stop("`predict_numeric()` is for predicting numeric outcomes.  ",
+         "Use `predict_class()` or `predict_classprob()` for ",
          "classification models.", call. = FALSE)
 
   if (!any(names(object$spec$method) == "numeric"))
     stop("No prediction module defined for this model.", call. = FALSE)
 
+  if (inherits(object$fit, "try-error")) {
+    warning("Model fit failed; cannot make predictions.", call. = FALSE)
+    return(NULL)
+  }
+
   new_data <- prepare_data(object, new_data)
 
   # preprocess data
@@ -40,9 +45,9 @@ predict_numeric.model_fit <- function (object, new_data, ...) {
 }
 
 
-#' @export
-#' @keywords internal
-#' @rdname other_predict
-#' @inheritParams predict_numeric.model_fit
-predict_numeric <- function (object, ...)
+# @export
+# @keywords internal
+# @rdname other_predict
+# @inheritParams predict_numeric.model_fit
+predict_numeric <- function(object, ...)
   UseMethod("predict_numeric")
