@@ -56,7 +56,7 @@ test_that('spark execution', {
   )
 
   expect_error(
-    spark_class_pred_class <- predict_class(spark_class_fit, churn_logit_te),
+    spark_class_pred_class <- predict(spark_class_fit, churn_logit_te),
     regexp = NA
   )
 
@@ -73,7 +73,7 @@ test_that('spark execution', {
   )
 
   expect_error(
-    spark_class_prob_classprob <- predict_classprob(spark_class_fit, churn_logit_te),
+    spark_class_prob_classprob <- predict(spark_class_fit, churn_logit_te, type = "prob"),
     regexp = NA
   )
 
